@@ -5,7 +5,6 @@
 #' @param x numeric vector  
 #' @param plot plot of distribution (TRUE/FALSE)
 #'
-#' @export
 #' @return A vector with the following values
 #' @return     min Minimum           
 #' @return     25th  25th percentile     
@@ -30,24 +29,25 @@
 #'     x <- runif(1000,0,100)
 #'     ( d <- moments(x, plot=TRUE) )
 #'     ( mode.x <- moments(x, plot=FALSE)[16] )
-#'   
+#'  
+#' @export 
 moments <- function(x, plot = FALSE) {
     if (!length(x) >= 3) 
         stop("Not enought values to represent a distribution")
-    skew <- function(x, na.rm = FALSE) {
+    .skew <- function(x, na.rm = FALSE) {
         if (na.rm) 
             x <- x[!is.na(x)]
-        sum((x - mean(x))^3)/(length(x) * sd(x)^3)
+        sum((x - mean(x))^3)/(length(x) * stats::sd(x)^3)
     }
-    kurt <- function(x, na.rm = FALSE) {
+    .kurt <- function(x, na.rm = FALSE) {
         if (na.rm) 
             x <- x[!is.na(x)]
-        sum((x - mean(x))^4)/(length(x) * var(x)^2) - 3
+        sum((x - mean(x))^4)/(length(x) * stats::var(x)^2) - 3
     }
-    cv <- function(x) {
-        (sd(x)/mean(x)) * 100
+    .cv <- function(x) {
+        (stats::sd(x)/mean(x)) * 100
     }
-    means <- function(x) {
+    .means <- function(x) {
         if (any(x < 0)) 
             stop("need positive data")
         geometric <- function(x) {
@@ -61,15 +61,15 @@ moments <- function(x, plot = FALSE) {
         }
         (x <- c(arithmetic(x), harmonic(x), geometric(x)))
     }
-    dmode <- function(x) {
-        den <- density(x, kernel = c("gaussian"))
+    .dmode <- function(x) {
+        den <- stats::density(x, kernel = c("gaussian"))
         (den$x[den$y == max(den$y)])
     }
-    n.modes <- function(x) {
-        den <- density(x, kernel = c("gaussian"))
-        den.s <- smooth.spline(den$x, den$y, all.knots = TRUE, spar = 0.8)
-        s.0 <- predict(den.s, den.s$x, deriv = 0)
-        s.1 <- predict(den.s, den.s$x, deriv = 1)
+    .n.modes <- function(x) {
+        den <- stats::density(x, kernel = c("gaussian"))
+        den.s <- stats::smooth.spline(den$x, den$y, all.knots = TRUE, spar = 0.8)
+        s.0 <- stats::predict(den.s, den.s$x, deriv = 0)
+        s.1 <- stats::predict(den.s, den.s$x, deriv = 1)
         s.derv <- data.frame(s0 = s.0$y, s1 = s.1$y)
         nmodes <- length(rle(den.sign <- sign(s.derv$s1))$values)/2
         if ((nmodes > 10) == TRUE) {
@@ -80,19 +80,19 @@ moments <- function(x, plot = FALSE) {
         }
         (nmodes)
     }
-    r <- c(min(x), quantile(x, 0.25), means(x)[1], means(x)[2], means(x)[3], quantile(x, 0.5), quantile(x, 0.75), 
-        max(x), sd(x), var(x), cv(x), mad(x), skew(x), kurt(x), n.modes(x), dmode(x))
+    r <- c(min(x), stats::quantile(x, 0.25), .means(x)[1], .means(x)[2], .means(x)[3], stats::quantile(x, 0.5), stats::quantile(x, 0.75), 
+        max(x), stats::sd(x), stats::var(x), .cv(x), stats::mad(x), .skew(x), .kurt(x), .n.modes(x), .dmode(x))
     names(r) <- c("min", "25th", "mean", "hmean", "gmean", "median", "75th", "max", "stdv", "var", "cv", "mad", "skew", 
         "kurt", "nmodes", "mode")
     if (plot == TRUE) {
-        plot(density(x), type = "n", main = "", ylab = "DENSITY", xlab = "RANGE", )
-        polygon(density(x), col = "blue")
-        abline(v = min(x), lty = 1, lwd = 1, col = "black")
-        abline(v = max(x), lty = 1, lwd = 1, col = "black")
-        abline(v = quantile(x, 0.25), lty = 2, lwd = 1, col = "black")
-        abline(v = quantile(x, 0.75), lty = 2, lwd = 1, col = "black")
-        abline(v = dmode(x), lty = 3, lwd = 1, col = "red")
-        legend("topright", lty = c(1, 1, 2, 2, 3), lwd = c(1, 1, 1, 1, 1), bty = "n", legend = c("MIN", "MAX", "25th", 
+        graphics::plot(stats::density(x), type = "n", main = "", ylab = "DENSITY", xlab = "RANGE", )
+        graphics::polygon(stats::density(x), col = "blue")
+        graphics::abline(v = min(x), lty = 1, lwd = 1, col = "black")
+        graphics::abline(v = max(x), lty = 1, lwd = 1, col = "black")
+        graphics::abline(v = stats::quantile(x, 0.25), lty = 2, lwd = 1, col = "black")
+       graphics::abline(v = stats::quantile(x, 0.75), lty = 2, lwd = 1, col = "black")
+        graphics::abline(v = .dmode(x), lty = 3, lwd = 1, col = "red")
+        graphics::legend("topright", lty = c(1, 1, 2, 2, 3), lwd = c(1, 1, 1, 1, 1), bty = "n", legend = c("MIN", "MAX", "25th", 
             "75th", "MODE"), col = c("black", "black", "black", "black", "red"))
     }
     return(r)
